@@ -26,6 +26,7 @@
 #include "buffermodel.h"
 #include "buffersettings.h"
 #include "client.h"
+#include "clientignorelistmanager.h"
 #include "clientsettings.h"
 #include "ircchannel.h"
 #include "network.h"
@@ -250,6 +251,10 @@ void BufferItem::updateActivityLevel(const Message &msg) {
   if(msg.flags() & Message::Self)	// don't update activity for our own messages
     return;
 
+  if (Client::ignoreListManager()
+      && Client::ignoreListManager()->match(msg, qobject_cast<NetworkItem *>(parent())->networkName()))
+    return;
+
   if(msg.msgId() <= lastSeenMsgId())
     return;
 
@@ -1022,6 +1027,7 @@ void NetworkModel::setLastSeenMsgId(const BufferId &bufferId, const MsgId &msgId
     return;
   }
   bufferItem->setLastSeenMsgId(msgId);
+  emit lastSeenMsgSet(bufferId, msgId);
 }
 
 void NetworkModel::setMarkerLineMsgId(const BufferId &bufferId, const MsgId &msgId) {
@@ -1032,6 +1038,7 @@ void NetworkModel::setMarkerLineMsgId(const BufferId &bufferId, const MsgId &msg
     return;
   }
   bufferItem->setMarkerLineMsgId(msgId);
+  emit markerLineSet(bufferId, msgId);
 }
 
 void NetworkModel::updateBufferActivity(Message &msg) {
@@ -1087,7 +1094,7 @@ void NetworkModel::updateBufferActivity(BufferItem *bufferItem, const Message &m
 
   bufferItem->updateActivityLevel(msg);
   if(bufferItem->isCurrentBuffer())
-    emit setLastSeenMsg(bufferItem->bufferId(), msg.msgId());
+    emit requestSetLastSeenMsg(bufferItem->bufferId(), msg.msgId());
 }
 
 void NetworkModel::setBufferActivity(const BufferId &bufferId, BufferInfo::ActivityLevel level) {
