@@ -104,11 +104,16 @@ int main(int argc, char **argv) {
   cliParser->addOption("listen <address>[,<address[,...]]>", 0, "The address(es) quasselcore will listen on", "::,0.0.0.0");
   cliParser->addOption("port <port>",'p', "The port quasselcore will listen at", QString("4242"));
   cliParser->addSwitch("norestore", 'n', "Don't restore last core's state");
-  cliParser->addOption("logfile <path>", 'l', "Path to logfile");
   cliParser->addOption("loglevel <level>", 'L', "Loglevel Debug|Info|Warning|Error", "Info");
-  cliParser->addOption("select-backend <backendidentifier>", 0, "Starts an interactive session and switches your current storage backend to the new one. Attempts a merge if the new backend is uninitialized and the old backend supports migration. Otherwise prompts for new user credentials!");
+#ifdef HAVE_SYSLOG
+  cliParser->addSwitch("syslog", 0, "Log to syslog");
+#endif
+  cliParser->addOption("logfile <path>", 'l', "Log to a file");
+  cliParser->addOption("select-backend <backendidentifier>", 0, "Switch storage backend (migrating data if possible)");
   cliParser->addSwitch("add-user", 0, "Starts an interactive session to add a new core user");
   cliParser->addOption("change-userpass <username>", 0, "Starts an interactive session to change the password of the user identified by username");
+  cliParser->addSwitch("oidentd", 0, "Enable oidentd integration");
+  cliParser->addOption("oidentd-conffile <file>", 0, "Set path to oidentd configuration file");
 #endif
 
 #ifdef HAVE_KDE
