@@ -34,10 +34,11 @@
 #  include <QTcpServer>
 #endif
 
-#include "storage.h"
 #include "bufferinfo.h"
 #include "message.h"
+#include "oidentdconfiggenerator.h"
 #include "sessionthread.h"
+#include "storage.h"
 #include "types.h"
 
 class CoreSession;
@@ -404,6 +405,8 @@ public:
 
   static inline QTimer &syncTimer() { return instance()->_storageSyncTimer; }
 
+  inline OidentdConfigGenerator *oidentdConfigGenerator() const { return _oidentdConfigGenerator; }
+
   static const int AddClientEventId;
 
 public slots:
@@ -472,6 +475,8 @@ private:
   QTcpServer _server, _v6server;
 #endif
 
+  OidentdConfigGenerator *_oidentdConfigGenerator;
+
   QHash<QTcpSocket *, quint32> blocksizes;
   QHash<QTcpSocket *, QVariantMap> clientInfo;
 
