@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2010 by the Quassel Project                        *
+ *   Copyright (C) 2005-2012 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -46,6 +46,9 @@ Cipher *CoreIrcChannel::cipher() const {
 }
 
 void CoreIrcChannel::setEncrypted(bool e) {
+  if(!Cipher::neededFeaturesAvailable())
+    return;
+
   if(e) {
     if(topic().isEmpty())
       return;
