@@ -41,10 +41,9 @@
 #include "coresession.h"
 
 class CoreIdentity;
-class IrcServerHandler;
 class CoreUserInputHandler;
-class CtcpHandler;
 class CoreIgnoreListManager;
+class Event;
 
 class CoreNetwork : public Network {
   SYNCABLE_OBJECT
@@ -59,9 +58,7 @@ public:
   inline CoreSession *coreSession() const { return _coreSession; }
   inline CoreNetworkConfig *networkConfig() const { return coreSession()->networkConfig(); }
 
-  inline IrcServerHandler *ircServerHandler() const { return _ircServerHandler; }
   inline CoreUserInputHandler *userInputHandler() const { return _userInputHandler; }
-  inline CtcpHandler *ctcpHandler() const { return _ctcpHandler; }
   inline CoreIgnoreListManager *ignoreListManager() { return coreSession()->ignoreListManager(); }
 
   //! Decode a string using the server (network) decoding.
@@ -88,6 +85,13 @@ public:
 
   inline UserId userId() const { return _coreSession->user(); }
 
+  inline QAbstractSocket::SocketState socketState() const { return socket.state(); }
+  inline bool socketConnected() const { return socket.state() == QAbstractSocket::ConnectedState; }
+  inline QHostAddress localAddress() const { return socket.localAddress(); }
+  inline QHostAddress peerAddress() const { return socket.peerAddress(); }
+  inline quint16 localPort() const { return socket.localPort(); }
+  inline quint16 peerPort() const { return socket.peerPort(); }
+
 public slots:
   virtual void setMyNick(const QString &mynick);
 
@@ -148,6 +152,10 @@ signals:
   void quitRequested(NetworkId networkId);
   void sslErrors(const QVariant &errorData);
 
+  void newEvent(Event *event);
+  void socketInitialized(const CoreIdentity *identity, const QHostAddress &localAddress, quint16 localPort, const QHostAddress &peerAddress, quint16 peerPort);
+  void socketDisconnected(const CoreIdentity *identity, const QHostAddress &localAddress, quint16 localPort, const QHostAddress &peerAddress, quint16 peerPort);
+
 protected:
   inline virtual IrcChannel *ircChannelFactory(const QString &channelname) { return new CoreIrcChannel(channelname, this); }
   inline virtual IrcUser *ircUserFactory(const QString &hostmask) { return new CoreIrcUser(hostmask, this); }
@@ -193,9 +201,7 @@ private:
   QTcpSocket socket;
 #endif
 
-  IrcServerHandler *_ircServerHandler;
   CoreUserInputHandler *_userInputHandler;
-  CtcpHandler *_ctcpHandler;
 
   QHash<QString, QString> _channelKeys;  // stores persistent channels and their passwords, if any
 
