@@ -18,28 +18,33 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#include "coresession.h"
+
 #include <QtScript>
 
 #include "core.h"
-#include "coresession.h"
 #include "coreuserinputhandler.h"
-#include "signalproxy.h"
 #include "corebuffersyncer.h"
 #include "corebacklogmanager.h"
 #include "corebufferviewmanager.h"
-#include "coreirclisthelper.h"
-#include "corenetworkconfig.h"
-#include "storage.h"
-
 #include "coreidentity.h"
-#include "corenetwork.h"
-#include "ircuser.h"
-#include "ircchannel.h"
-
-#include "util.h"
-#include "coreusersettings.h"
-#include "logger.h"
 #include "coreignorelistmanager.h"
+#include "coreirclisthelper.h"
+#include "corenetwork.h"
+#include "corenetworkconfig.h"
+#include "coresessioneventprocessor.h"
+#include "coreusersettings.h"
+#include "ctcpparser.h"
+#include "eventmanager.h"
+#include "eventstringifier.h"
+#include "ircchannel.h"
+#include "ircparser.h"
+#include "ircuser.h"
+#include "logger.h"
+#include "messageevent.h"
+#include "signalproxy.h"
+#include "storage.h"
+#include "util.h"
 
 class ProcessMessagesEvent : public QEvent {
 public:
@@ -57,6 +62,11 @@ CoreSession::CoreSession(UserId uid, bool restoreState, QObject *parent)
     _ircListHelper(new CoreIrcListHelper(this)),
     _networkConfig(new CoreNetworkConfig("GlobalNetworkConfig", this)),
     _coreInfo(this),
+    _eventManager(new EventManager(this)),
+    _eventStringifier(new EventStringifier(this)),
+    _sessionEventProcessor(new CoreSessionEventProcessor(this)),
+    _ctcpParser(new CtcpParser(this)),
+    _ircParser(new IrcParser(this)),
     scriptEngine(new QScriptEngine(this)),
     _processMessages(false),
     _ignoreListManager(this)
@@ -87,6 +97,15 @@ CoreSession::CoreSession(UserId uid, bool restoreState, QObject *parent)
   loadSettings();
   initScriptEngine();
 
+  eventManager()->registerObject(ircParser(), EventManager::NormalPriority);
+  eventManager()->registerObject(sessionEventProcessor(), EventManager::HighPriority); // needs to process events *before* the stringifier!
+  eventManager()->registerObject(ctcpParser(), EventManager::NormalPriority);
+  eventManager()->registerObject(eventStringifier(), EventManager::NormalPriority);
+  eventManager()->registerObject(this, EventManager::LowPriority); // for sending MessageEvents to the client
+   // some events need to be handled after msg generation
+  eventManager()->registerObject(sessionEventProcessor(), EventManager::LowPriority, "lateProcess");
+  eventManager()->registerObject(ctcpParser(), EventManager::LowPriority, "send");
+
   // periodically save our session state
   connect(&(Core::instance()->syncTimer()), SIGNAL(timeout()), this, SLOT(saveSessionState()));
 
@@ -240,6 +259,14 @@ void CoreSession::recvStatusMsgFromServer(QString msg) {
   emit displayStatusMsg(net->networkName(), msg);
 }
 
+void CoreSession::processMessageEvent(MessageEvent *event) {
+  recvMessageFromServer(event->networkId(), event->msgType(), event->bufferType(),
+                        event->target().isNull()? "" : event->target(),
+                        event->text().isNull()? "" : event->text(),
+                        event->sender().isNull()? "" : event->sender(),
+                        event->msgFlags());
+}
+
 QList<BufferInfo> CoreSession::buffers() const {
   return Core::requestBuffers(user());
 }
@@ -378,7 +405,7 @@ void CoreSession::createIdentity(const Identity &identity, const QVariantMap &ad
 void CoreSession::createIdentity(const CoreIdentity &identity) {
   CoreIdentity *coreIdentity = new CoreIdentity(identity, this);
   _identities[identity.id()] = coreIdentity;
-  // CoreIdentity has it's own synchronize method since it's "private" sslManager needs to be synced aswell
+  // CoreIdentity has its own synchronize method since its "private" sslManager needs to be synced as well
   coreIdentity->synchronize(signalProxy());
   connect(coreIdentity, SIGNAL(updated()), this, SLOT(updateIdentityBySender()));
   emit identityCreated(*coreIdentity);
@@ -434,6 +461,7 @@ void CoreSession::createNetwork(const NetworkInfo &info_, const QStringList &per
     connect(net, SIGNAL(displayMsg(NetworkId, Message::Type, BufferInfo::Type, const QString &, const QString &, const QString &, Message::Flags)),
                  SLOT(recvMessageFromServer(NetworkId, Message::Type, BufferInfo::Type, const QString &, const QString &, const QString &, Message::Flags)));
     connect(net, SIGNAL(displayStatusMsg(QString)), SLOT(recvStatusMsgFromServer(QString)));
+    connect(net, SIGNAL(disconnected(NetworkId)), SIGNAL(networkDisconnected(NetworkId)));
 
     net->setNetworkInfo(info);
     net->setProxy(signalProxy());
