@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2010 by the Quassel Project                        *
+ *   Copyright (C) 2005-2012 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,7 +21,7 @@
 
 #include "util.h"
 
-#include "ctcphandler.h"
+#include "ctcpparser.h"
 
 #include <QRegExp>
 
@@ -154,7 +154,8 @@ void CoreUserInputHandler::handleCtcp(const BufferInfo &bufferInfo, const QStrin
     message = QString::number(now);
   }
 
-  network()->ctcpHandler()->query(nick, ctcpTag, message);
+  // FIXME make this a proper event
+  coreNetwork()->coreSession()->ctcpParser()->query(coreNetwork(), nick, ctcpTag, message);
   emit displayMsg(Message::Action, BufferInfo::StatusBuffer, "", verboseMessage, network()->myNick());
 }
 
@@ -163,6 +164,9 @@ void CoreUserInputHandler::handleDelkey(const BufferInfo &bufferInfo, const QStr
   if(!bufferInfo.isValid())
     return;
 
+  if(!Cipher::neededFeaturesAvailable())
+    return;
+
   QStringList parms = msg.split(' ', QString::SkipEmptyParts);
 
   if(parms.isEmpty() && !bufferInfo.bufferName().isEmpty())
@@ -309,7 +313,8 @@ void CoreUserInputHandler::handleList(const BufferInfo &bufferInfo, const QStrin
 
 void CoreUserInputHandler::handleMe(const BufferInfo &bufferInfo, const QString &msg) {
   if(bufferInfo.bufferName().isEmpty()) return; // server buffer
-  network()->ctcpHandler()->query(bufferInfo.bufferName(), "ACTION", msg);
+  // FIXME make this a proper event
+  coreNetwork()->coreSession()->ctcpParser()->query(coreNetwork(), bufferInfo.bufferName(), "ACTION", msg);
   emit displayMsg(Message::Action, bufferInfo.type(), bufferInfo.bufferName(), msg, network()->myNick(), Message::Self);
 }
 
@@ -414,7 +419,7 @@ void CoreUserInputHandler::handleQuery(const BufferInfo &bufferInfo, const QStri
   QString target = msg.section(' ', 0, 0);
   QString message = msg.section(' ', 1);
   if(message.isEmpty())
-    emit displayMsg(Message::Server, BufferInfo::QueryBuffer, target, tr("Starting query with ") + target, network()->myNick(), Message::Self);
+    emit displayMsg(Message::Server, BufferInfo::QueryBuffer, target, tr("Starting query with %1").arg(target), network()->myNick(), Message::Self);
   else
     emit displayMsg(Message::Plain, BufferInfo::QueryBuffer, target, message, network()->myNick(), Message::Self);
   handleMsg(bufferInfo, msg);
@@ -452,6 +457,9 @@ void CoreUserInputHandler::handleSetkey(const BufferInfo &bufferInfo, const QStr
   if(!bufferInfo.isValid())
     return;
 
+  if(!Cipher::neededFeaturesAvailable())
+    return;
+
   QStringList parms = msg.split(' ', QString::SkipEmptyParts);
 
   if(parms.count() == 1 && !bufferInfo.bufferName().isEmpty())
@@ -483,6 +491,44 @@ void CoreUserInputHandler::handleSetkey(const BufferInfo &bufferInfo, const QStr
 #endif
 }
 
+void CoreUserInputHandler::handleShowkey(const BufferInfo &bufferInfo, const QString &msg) {
+#ifdef HAVE_QCA2
+  if(!bufferInfo.isValid())
+    return;
+
+  if(!Cipher::neededFeaturesAvailable())
+    return;
+
+  QStringList parms = msg.split(' ', QString::SkipEmptyParts);
+
+  if(parms.isEmpty() && !bufferInfo.bufferName().isEmpty())
+    parms.prepend(bufferInfo.bufferName());
+
+  if(parms.isEmpty()) {
+    emit displayMsg(Message::Info, bufferInfo.bufferName(), "",
+                    tr("[usage] /showkey <nick|channel> shows the encryption key for nick or channel or just /showkey when in a channel or query."));
+    return;
+  }
+
+  QString target = parms.at(0);
+  QByteArray key = network()->cipherKey(target);
+
+  if(key.isEmpty()) {
+    emit displayMsg(Message::Info, bufferInfo.bufferName(), tr("No key has been set for %1.").arg(target));
+    return;
+  }
+
+  emit displayMsg(Message::Info, bufferInfo.bufferName(), tr("The key for %1 is %2").arg(target).arg(QString(key)));
+
+#else
+  Q_UNUSED(msg)
+  emit displayMsg(Message::Error, bufferInfo.bufferName(), "", tr("Error: Setting an encryption key requires Quassel to have been built "
+                                                                  "with support for the Qt Cryptographic Architecture (QCA2) library. "
+                                                                  "Contact your distributor about a Quassel package with QCA2 "
+                                                                  "support, or rebuild Quassel with QCA2 present."));
+#endif
+}
+
 void CoreUserInputHandler::handleTopic(const BufferInfo &bufferInfo, const QString &msg) {
   if(bufferInfo.bufferName().isEmpty())
     return;
@@ -636,6 +682,9 @@ QByteArray CoreUserInputHandler::encrypt(const QString &target, const QByteArray
   if(message_.isEmpty())
     return message_;
 
+  if(!Cipher::neededFeaturesAvailable())
+    return message_;
+
   Cipher *cipher = network()->cipher(target);
   if(!cipher)
     return message_;
