@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2010 by the Quassel Project                        *
+ *   Copyright (C) 2005-2012 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This contains code from KStatusNotifierItem, part of the KDE libs     *
@@ -222,14 +222,14 @@ QString StatusNotifierItem::title() const {
 
 QString StatusNotifierItem::iconName() const {
   if(state() == Passive)
-    return QString("quassel_inactive");
+    return QString("quassel-inactive");
   else
     return QString("quassel");
 }
 
 QString StatusNotifierItem::attentionIconName() const {
   if(animationEnabled())
-    return QString("quassel_message");
+    return QString("quassel-message");
   else
     return QString("quassel");
 }
