@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2010 by the Quassel Project                        *
+ *   Copyright (C) 2005-2012 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -39,9 +39,9 @@ SystemTray::SystemTray(QWidget *parent)
   _mode(Invalid),
   _state(Passive),
   _shouldBeVisible(true),
-  _passiveIcon(DesktopIcon("quassel_inactive")),
+  _passiveIcon(DesktopIcon("quassel-inactive")),
   _activeIcon(DesktopIcon("quassel")),
-  _needsAttentionIcon(DesktopIcon("quassel_message")),
+  _needsAttentionIcon(DesktopIcon("quassel-message")),
   _trayMenu(0),
   _associatedWidget(parent)
 {
