@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2010 by the Quassel Project                        *
+ *   Copyright (C) 2005-2012 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This contains code from KStatusNotifierItem, part of the KDE libs     *
@@ -201,7 +201,7 @@ bool GraphicalUi::checkMainWidgetVisibility(bool perform) {
   }
 #else
 
-  if(!mainWidget()->isVisible() || mainWidget()->isMinimized()) {
+  if(!mainWidget()->isVisible() || mainWidget()->isMinimized() || !mainWidget()->isActiveWindow()) {
     if(perform)
       minimizeRestore(true);
     return true;
