@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2010 by the Quassel Project                        *
+ *   Copyright (C) 2005-2012 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -658,7 +658,7 @@ void MultiLineEdit::on_textChanged() {
       clear();
 
       if(lines.count() >= 4) {
-        QString msg = tr("Do you really want to paste %n lines?", "", lines.count());
+        QString msg = tr("Do you really want to paste %n line(s)?", "", lines.count());
         msg += "<p>";
         for(int i = 0; i < 4; i++) {
           msg += Qt::escape(lines[i].left(40));
