@@ -230,6 +230,8 @@ quint64 QssParser::parseFormatType(const QString &decl) {
       fmtType |= UiStyle::NetsplitJoinMsg;
     else if(msgType == "netsplit-quit")
       fmtType |= UiStyle::NetsplitQuitMsg;
+    else if(msgType == "invite")
+      fmtType |= UiStyle::InviteMsg;
     else {
       qWarning() << Q_FUNC_INFO << tr("Invalid message type in %1").arg(decl);
     }
@@ -466,6 +468,7 @@ QBrush QssParser::parseBrush(const QString &str, bool *ok) {
       return QBrush();
     }
     QLinearGradient gradient(x1, y1, x2, y2);
+    gradient.setCoordinateMode(QGradient::ObjectBoundingMode);
     gradient.setStops(stops);
     if(ok)
       *ok = true;
@@ -487,6 +490,7 @@ QBrush QssParser::parseBrush(const QString &str, bool *ok) {
       return QBrush();
     }
     QConicalGradient gradient(cx, cy, angle);
+    gradient.setCoordinateMode(QGradient::ObjectBoundingMode);
     gradient.setStops(stops);
     if(ok)
       *ok = true;
@@ -510,6 +514,7 @@ QBrush QssParser::parseBrush(const QString &str, bool *ok) {
       return QBrush();
     }
     QRadialGradient gradient(cx, cy, radius, fx, fy);
+    gradient.setCoordinateMode(QGradient::ObjectBoundingMode);
     gradient.setStops(stops);
     if(ok)
       *ok = true;
